#
# spec file for package systemd-presets-common-SUSE
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define generic_name systemd-presets-branding

Name:           systemd-presets-common-SUSE
Version:        15
Release:        34.1
Summary:        Systemd default presets for SUSE distributions
License:        GPL-2.0-or-later
Group:          System/Base
Source0:        default-SUSE.preset
Source2:        99-default-disable.preset
Source3:        branding-preset-states
Source4:        default-SUSE-user.preset
BuildRequires:  pkgconfig(systemd)
#!BuildIgnore:  systemd-presets-branding
PreReq:         coreutils
Supplements:    systemd
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

Requires(pre):  bash
Requires(post): bash

%description
Default presets for systemd on SUSE based distributions.

%prep
%setup -q -T -c

%build

%install
mkdir -p %{buildroot}%{_prefix}/lib/%{generic_name}
mkdir -p %{buildroot}%{_prefix}/lib/systemd/system-preset
mkdir -p %{buildroot}%{_prefix}/lib/systemd/user-preset
# everything that must be enabled to have a working system.
# shared across all brands
install -m644 %{SOURCE0}  %{buildroot}%{_prefix}/lib/systemd/system-preset/95-default-SUSE.preset
install -m644 %{SOURCE2}  %{buildroot}%{_prefix}/lib/systemd/system-preset/
install -m755 %{SOURCE3}  %{buildroot}%{_prefix}/lib/%{generic_name}/
install -m644 %{SOURCE4}  %{buildroot}%{_prefix}/lib/systemd/user-preset/95-default-SUSE.preset

%pre
# On initial installation, branding-preset-states does not yet exist,
# which is why we also check for the file to be present/executable
if [ $1 -gt 1 -a -x %{_prefix}/lib/%{generic_name}/branding-preset-states ] ; then
	#
	# Save the old state so we can detect which package have its
	# default changed later.
	#
	# Note: the old version of the script is used here.
	#
	%{_prefix}/lib/%{generic_name}/branding-preset-states save
	%{_prefix}/lib/%{generic_name}/branding-preset-states save user
elif [ $1 -eq 1 ]; then
  touch /run/rpm-%{name}-preset-all
fi

%post
if [ $1 -gt 1 ] ; then
	#
	# Now that the updated presets are installed, find the ones
	# that have been changed and apply "systemct preset" on them.
	#
	%{_prefix}/lib/%{generic_name}/branding-preset-states apply-changes
	%{_prefix}/lib/%{generic_name}/branding-preset-states apply-changes user
fi

%posttrans
if [ -f /run/rpm-%{name}-preset-all ]; then
  # Enable all services, which were installed before systemd
  # Don't disable services, since this would disable the
  # complete network stack.
  systemctl preset-all --preset-mode=enable-only
  systemctl preset-all --preset-mode=enable-only --global
fi
rm -f /run/rpm-%{name}-preset-all

%files
%defattr(-,root,root)
%{_prefix}/lib/%{generic_name}/
%{_prefix}/lib/systemd/system-preset/*
%{_prefix}/lib/systemd/user-preset/*

%changelog
* Mon Aug 26 2024 Thorsten Kukuk <kukuk@suse.com>
- Enable soft-reboot-cleanup.service to make soft-reboot possible
  with container and/or firewalld.
* Thu Apr 25 2024 Simon Lees <sflees@suse.de>
- Add presets to enable dbus-broker.service for both system and user
  due to naming socket activation doesn't work directly.
- Order .presets file alphabetically via service.
* Thu Feb  1 2024 Michal Suchanek <msuchanek@suse.com>
- Split hcn-init.service to hcn-init-NetworkManager and hcn-init-wicked
  (bsc#1200731 ltc#198485 https://github.com/ibm-power-utilities/powerpc-utils/pull/84)
  Support both the old and new service to avoid complex version interdependency.
* Thu Oct 19 2023 Matthias Gerstner <matthias.gerstner@suse.com>
- nvme-cli: enable nvmf-autoconnect.service for improved user experience
  (bsc#1216369).
* Tue Jun 20 2023 Antonio Larrosa <alarrosa@suse.com>
- Fix another case of systemctl being called with an empty
  argument. This if a preemptive fix for a similar issue to
  bsc#1212496.
* Mon Jun 19 2023 Thorsten Kukuk <kukuk@suse.com>
- Don't call systemctl list-unit-files with an empty argument,
  this will break enabling of system unit files [bsc#1212496]
* Fri Jun  9 2023 Thorsten Kukuk <kukuk@suse.com>
- Add wtmpdb-update-boot.service and wtmpdb-rotate.timer to enable
  wtmpdb as Y2038 safe wtmp replacement
* Tue Feb  7 2023 Fabian Vogt <fvogt@suse.com>
- Enable spice-vdagent.service and xdg-user-dirs.service by default
  (boo#1201728)
* Thu Dec 15 2022 Franck Bui <fbui@suse.com>
- Enable systemd-pstore.service by default (jsc#PED-2663)
* Wed Nov 16 2022 Matthias Gerstner <matthias.gerstner@suse.com>
- enable user side autostart of drkonqi socket (bsc#1203493).
* Tue Jun 14 2022 Antonio Larrosa <alarrosa@suse.com>
- Modify branding-preset-states to fix systemd-presets-common-SUSE
  not enabling new user systemd service preset configuration just
  as it handles system service presets. By passing an (optional)
  second parameter "user", the save/apply-changes commands now
  work with user services instead of system ones (boo#1200485)
* Mon May 23 2022 Ignaz Forster <iforster@suse.com>
- enable ignition-delete-config by default (bsc#1199524)
* Mon Apr 11 2022 Jonathan Kang <songchuan.kang@suse.com>
- Enable appstream-sync-cache.service by default(bsc#1197684).
* Tue Feb  1 2022 Kirk Allan <kallan@suse.com>
- enable vgauthd service for VMWare by default (bsc#1195251)
* Fri Nov  5 2021 Antonio Larrosa <alarrosa@suse.com>
- Replace the pipewire-media-session preset with a wireplumber
  user service preset to enable it by default (bsc#1200485).
* Thu Oct  7 2021 Cristian Rodríguez <crrodriguez@opensuse.org>
- Haveged as a daemon is no longer required since kernel 5.6
  do not enable by default.
* Thu Jun 10 2021 Dr. Werner Fink <werner@suse.de>
- To make update of package man work with its new upstream timer
  and service units both called man-db enable also man-db.timer
* Thu May 27 2021 Antonio Larrosa <alarrosa@suse.com>
- When installing the systemd-presets-common-SUSE package for the
  first time in a new system, it might happen that some services
  are installed before systemd so the %%systemd_pre/post macros
  would not work. This is handled by enabling all preset services
  in this package's %%posttrans section but it wasn't enabling
  user services, just system services. Now it enables also the
  user services installed before this package, thus fixing
  boo#1186561
* Wed Apr  7 2021 Michal Suchanek <msuchanek@suse.com>
- Enable hcn-init.service for HNV on POWER (bsc#1184136 ltc#192155).
* Wed Mar 10 2021 Frederic Crozat <fcrozat@suse.com>
- Enable user service pipewire-media-session.service (used with
  pipewire >= 0.3.23).
* Thu Mar  4 2021 Antonio Larrosa <alarrosa@suse.com>
- Enable user services pipewire.socket and pipewire-pulse.socket
  (boo#1183012).
* Wed Aug 26 2020 Fabian Vogt <fvogt@suse.com>
- Enable btrfsmaintenance-refresh.path and disable
  btrfsmaintenance-refresh.service to avoid needless refresh on boot
  (boo#1165780)
* Tue Aug 11 2020 Neal Gompa <ngompa13@gmail.com>
- Enable dnf-makecache.timer
* Wed Jun 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Thu Jun  6 2019 Ignaz Forster <iforster@suse.com>
- Enable ignition-firstboot-complete.service
* Mon Apr  1 2019 Andrew Daugherity <adaugherity@tamu.edu>
- Enable logwatch.timer (bsc#1112500).
* Thu Mar 14 2019 Simon Schricker <sschricker@suse.com>
- enable nvmefc-boot-connections.service to discover
  network-provided nvme drives on boot (bsc#1128428)
* Wed Jan 23 2019 psimons@suse.com
- Recent versions of mlocate don't use updatedb.timer any more.
  Instead, the unit is called mlocate.timer. [boo#1115408]
* Fri Jan 18 2019 sbrabec@suse.com
- branding-preset-states: Apply preset to all unit types
  (bsc#1121219).
- Rename 90-default-SUSE.preset to 95-default-SUSE.preset, so
  product branding takes precedence over common presets.
* Tue Jan 15 2019 tiwai@suse.de
- Add default user preset: currently containing only the new
  pulseaudio.socket (bsc#1083473)
* Fri Jan 11 2019 kukuk@suse.de
- Add issue-generator.path to make sure /etc/issue is really
  regenerated if snippets change [bsc#1116825]
* Wed Jan  9 2019 Rubén Torrero Marijnissen <rtorreromarijnissen@suse.com>
- Enable new unbound-anchor timer to keep root.key updated
  (bsc#1115417)
* Thu Dec 13 2018 Neil Brown <nfbrown@suse.com>
- Eanble new mdadm timers mdcheck_start.timer and  mdmonitor-oneshot.timer
  (bsc#1115407)
* Mon Nov 12 2018 meissner@suse.com
- mandb.timer: added as mandb moved from cron job to systemd
  timer (bsc#1115406)
* Tue Oct 30 2018 lnussel@suse.de
- disable ca-certificates.service as it needlessly slows down boot
  (boo#1088378). update-ca-certificates will still be triggered by
  the path when there are actual changes.
* Tue Sep 11 2018 meissner@suse.com
- enable machines.target for the systemd based containers (bsc#1107941)
* Wed Jul 11 2018 kukuk@suse.de
- Eanble smartd_generate_opts.path: generate new smartd option
  file if sysconfig variables changes.
* Wed Feb 28 2018 meissner@suse.com
- split out common service to be default enabled on all SUSE
  distributions from the branding. FATE#322139
* Mon Feb  5 2018 kukuk@suse.de
- Enable backup-rpmdb.timer, backup-sysconfig.timer and
  check-battery.timer, previously cron.daily jobs.
* Tue Jan  2 2018 sbrabec@suse.com
- Enable new kbdsettings.service (boo#1010880).
* Mon Jan  1 2018 wr@rosenauer.org
- enable pcscd socket activation by default to support smartcards
  out of the box (boo#1063983)
* Fri Dec 29 2017 zren@suse.com
- Enable lvm2-lvmpolld.socket by default (bsc#1074211)
* Tue Dec 19 2017 zren@suse.com
- Enable lvm2-monitor.service by default (bsc#1072492)
* Tue Dec 12 2017 kukuk@suse.de
- Don't disable services with preset-all in %%posttrans, the network
  is special and would be disabled.
* Mon Dec 11 2017 kukuk@suse.de
- If we do a fresh installation, call systemctl preset-all in the
  %%posttrans section. Some services need to be installed before
  systemd or do not strictly require systemd, so systemd would only
  be installed after them and the systemd units of this package
  never enabled.
* Mon Dec 11 2017 kukuk@suse.de
- Enable klog.service and rsyslog.service by default, currently
  they enable themself always in post install section.
* Wed Dec  6 2017 kukuk@suse.de
- Enable btrfs-*.timer by default, switch from cron to systemd.timer
- Enable btrfsmaintenance-refresh.service
* Thu Nov  9 2017 sckang@suse.com
- Enable ModemManager.service by default (bsc#1038402).
* Fri Nov  3 2017 olaf@aepfle.de
- Move common entries into default-SUSE.preset (bsc#1060676)
* Tue Oct 17 2017 olaf@aepfle.de
- Sort entries with :'<,'>!sort -t ' ' -k 2 (bsc#1060676)
* Tue Jun 20 2017 kukuk@suse.de
- Enable ca-certificates to run on boot and on demand to create
  database in /var/lib/ca-certificates
* Tue Mar 21 2017 meissner@suse.com
- removed duplicated iscsid.socket iscsid.servicce (bsc#1030161)
* Fri Mar 17 2017 sbrabec@suse.com
- Bump version to 12.2 to make version numbers consistent between
  SLE and Leap (boo#1029775).
- Remove superfluous uuidd.service. uuidd.socket is sufficient
  (bsc#1012850#c8).
* Tue Feb 21 2017 zren@suse.com
- Enable socket/service(s) for lvm2 (bsc#1011053)
* Fri Feb 10 2017 fbui@suse.com
- Enable by default uuidd shipped by util-linux (bsc#1012850)
  util-linux was previously shipping a preset file enabling uuidd by
  default. This is now done here as other packages are not supposed to
  ship their own preset rules.
  Also increase the package version so util-linux can conflict with
  the previous versions and hence will be updated *after* the new
  version of the presets package is. This is important otherwise if
  util-linux removed its preset file first, then the presets package
  would believe a new change in the presets and you enable again
  uuidd.
* Tue Jan 24 2017 dimstar@opensuse.org
- Enable the issue-generator.service by default: /etc/issue is in
  progress of no longer being a static file, but being generated by
  a service, which allows for much more flexible content (think
  ssh key fingerprint or similar).
* Thu Dec 15 2016 dimstar@opensuse.org
- Fix pre/post scripts:
  + On %%pre case, when updating from an old version of the package
    that did not yet contain
    %%{_prefix}/lib/%%{generic_name}/branding-preset-states, we can't
    start it. Add a check for execute permission on the script.
* Thu Dec  8 2016 fbui@suse.com
- Import preset macros from systemd-rpm-macro and convert them into
  scripts.
  Presets are not supposed to be shipped by other packages as the
  default policy needs to be reviewed by the secteam. Therefore don't
  encourage packagers to do that and make those macros private to this
  package.
  Also convert them into real scripts so they're much easier to
  maintain and debug. Also working in %%posttrans is unneeded as this
  package is assumed to be the only one to update the preset.
* Thu Dec  8 2016 fbui@suse.com
- There's no need to reload the daemon configuration as presets are
  not part of the dameon config.
* Tue Nov 29 2016 meissner@suse.com
- added snapper-cleanup.timer and snapper-timeline.timer (bsc#1011891)
* Tue Jun 14 2016 ken@suse.com
- enable vmblock-fuse service for VMWare by default (bsc#986277)
* Thu Jun  9 2016 lnussel@suse.de
- don't require systemd to avoid dependency loop (boo#983986)
* Tue May 31 2016 meissner@suse.com
- added a prereq for coreutils to make sure the macro in %%pre
  works when using touch and mkdir. (bsc#982337)
* Mon May  9 2016 trenn@suse.de
- enable mcelog by default instead of using an udev rule on
  /dev/mcelog (bsc#976781)
* Thu Mar 24 2016 meissner@suse.com
- enable remote-fs.target, getty@.service. (bsc#972489)
* Wed Dec 16 2015 lnussel@suse.de
- don't enable ModemManager and wpa_supplicant. Both will be started
  on demand (bnc#717130)
* Wed Dec 16 2015 eich@suse.com
- Add display-manager.service to defaults presets (boo#958880).
* Tue Dec  8 2015 sbrabec@suse.com
- Enable fstrim.timer and disable fstrim.service. TRIM should be
  performed once a week and not on every boot (FATE#317727).
  http://www.spinics.net/lists/util-linux-ng/msg09133.html
* Tue Aug  4 2015 sbrabec@suse.com
- Add %%systemd_preset_pre and %%systemd_preset_posttrans (fixes
  boo#921075 and all future requests to change service default).
* Wed Jul 15 2015 jkeil@suse.de
- Enable updatedb timer for mlocate package
  * Replaces cron.daily script
* Wed Jul 15 2015 jkeil@suse.de
- Enable timer for periodic password & group file integrity verification
* Wed Jul 15 2015 olaf@aepfle.de
- Remove xendomains.service from systemd preset file because it
  conflicts with libvirt-guests.service (bnc#937371)
  Its up to the admin to run systemctl enable xendomains.service
* Tue Jun 30 2015 crrodriguez@opensuse.org
- If selinux is used, restorecond should be enabled by default.
  The relevant unit only starts if the system was booted with
  selinux enabled
- Do not start acpid by default, its functionality is provided
  by logind nowadays.
* Wed Apr  1 2015 crrodriguez@opensuse.org
- Native systemd unit apparmor.service need to be enabled
  by default.
* Mon Mar  9 2015 meissner@suse.com
- enabled smartd by default (bnc#921075)
* Tue Jan 13 2015 olaf@aepfle.de
- enable xencommons and xendomains (bnc#897352)
* Fri Dec 19 2014 mlatimer@suse.com
- enable vmtoolsd service for VMWare by default (bnc#901272)
* Wed Dec  3 2014 lwang@suse.com
- remove: enable lvm2-lvmetad.service   (bnc#901859)
* Thu Nov 20 2014 gber@opensuse.org
- enable storage-fixup.service by default due to conversion
* Thu Jun 26 2014 glin@suse.com
- enable wpa_supplicant.service (bnc#860885 comment#20)
* Wed May 28 2014 lwang@suse.com
- enable lvm2-lvmetad.socket (bnc#878473)
  enable lvm2-lvmetad.service
* Fri Apr 11 2014 meissner@suse.com
- enable auditd, haveged and irqbalance services by default. bnc#872066
* Wed Apr  2 2014 crrodriguez@opensuse.org
- Enable the logrotate.timer that replaces the cron-based
  activation by default.
* Fri Mar  7 2014 matwey.kornilov@gmail.com
- Enable epmd.socket so that epmd.service can be properly
  socket-activated instead of forking by beam. The later leads to
  the issue when epmd is killed at the stop of the specific service
  and all erlang instances crashes as a consequence.
  Needed by erlang package. (bnc#869112)
* Thu Feb 13 2014 lduncan@suse.com
- Enable iscsi daemon socket and iscsi service as installed,
  so that iscsid.service can be socket-activated. (bnc#853300)
* Sat Feb  1 2014 ohering@suse.de
- Revert last change for hyper-v.rpm
  Both daemons are started on demand via udev rules.
* Wed Dec 18 2013 ohering@suse.de
- Enable hv_kvp_daemon and hv_vss_daemon from hyper-v pkg
* Thu Oct 17 2013 lduncan@suse.com
- Enable iscsid socket and iscsi service by default when
  installed (bnc#827654).
* Wed Jul 31 2013 fcrozat@suse.com
- Enable ModemManager.service is enabled when installed (it will be
  dbus-activated by NM).
* Thu Jul 25 2013 fcrozat@suse.com
- Rename main default file to 90-default-openSUSE.preset and move
  the "disable everything" part to a separate file
  "99-default-disable.preset". This allows fine tuning with
  additional files, if needed (same as Fedora).
* Fri May  3 2013 meissner@suse.com
- as we have multiversion kernels enabled by default, we also
  need to enable purge-kernels by default (bnc#818317).
* Fri Feb 22 2013 mt@suse.com
- Do not unconditionally enable NetworkManager service as this
  breaks running /etc/init.d/network on update (bnc#803058).
* Wed Oct 17 2012 fcrozat@suse.com
- Change location of presets with latest systemd.
* Tue Sep 11 2012 aj@suse.de
- Add nscd service (bnc#778981).
* Wed Jul  4 2012 fcrozat@suse.com
- Add cups units (service, path and socket) (bnc#769346).
* Mon Dec 12 2011 fcrozat@suse.com
- Add postfix (bnc#727403).
* Wed Oct 26 2011 lnussel@suse.de
- don't enable sysstat by default (bnc#725791)
* Mon Oct 17 2011 fcrozat@suse.com
- Add sysstat.service (bnc#723858).
* Sun Oct 16 2011 coolo@suse.com
- buildignore branding for systemd to avoid bootstrap cycle
* Fri Oct  7 2011 fcrozat@suse.com
- Add Yast2 FirstBoot and Second Stage.
* Thu Sep 29 2011 fcrozat@suse.com
- Don't enable avahi-dnsconfd.service after all.
* Thu Sep 29 2011 fcrozat@suse.com
- Enable avahi-daemon.service and avahi-dnsconfd.service
* Thu Sep 29 2011 fcrozat@suse.com
- Enable cron.service
* Mon Sep 26 2011 fcrozat@suse.com
- Initial package
